@@ -58,11 +58,6 @@ CardArea::CardArea()
   AttachModel(timerAction);
 }
 
-CardArea::~CardArea()
-{
-  UnattachModel(timerAction);
-}
-
 void CardArea::Unselect()
 {
   for (size_t i=0; i<entries.size(); i++) {
