@@ -39,11 +39,6 @@ FadeText::FadeText()
   AttachModel(timerAction);
 }
 
-FadeText::~FadeText()
-{
-  UnattachModel(timerAction);
-}
-
 void FadeText::Fade()
 {
   fadeStep--;
