@@ -22,13 +22,11 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Combo.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
-#include <Lum/WindowGroup.h>
 
 GameStartDialog::GameStartDialog(size_t points, size_t player)
  : commitAction(new Lum::Model::Action()),
@@ -44,28 +42,15 @@ GameStartDialog::GameStartDialog(size_t points, size_t player)
   AttachModel(this->points);
 }
 
-GameStartDialog::~GameStartDialog()
-{
-  UnattachModel(points);
-  UnattachModel(commitAction);
-
-  UnattachModel(GetClosedAction());
-}
-
 void GameStartDialog::PreInit()
 {
-  Lum::Button              *button;
   Lum::ButtonRow           *row;
   Lum::TextEditCombo       *pointsCombo;
   Lum::IndexCombo          *playerCombo;
   Lum::Label               *label;
   Lum::Panel               *vert;
-  Lum::WindowGroup         *wGroup;
   Lum::Model::ListTableRef tableModel;
 
-  wGroup=new Lum::WindowGroup();
-  wGroup->SetFlex(true,true);
-
   vert=new Lum::VPanel();
 
   label=new Lum::Label();
@@ -97,26 +82,11 @@ void GameStartDialog::PreInit()
 
   vert->Add(new Lum::VSpace());
 
-  row=new Lum::ButtonRow();
+  row=Lum::ButtonRow::CreateOkCancel(commitAction,GetClosedAction());
   row->SetFlex(true,false);
-
-  button=new Lum::Button(_ld(dlgButtonOk));
-  button->SetFlex(true,true);
-  button->SetModel(commitAction);
-  button->SetType(Lum::Button::typeCommit);
-  row->Add(button);
-
-  button=new Lum::Button(_ld(dlgButtonCancel));
-  button->SetFlex(true,true);
-  button->SetModel(GetClosedAction());
-  button->SetType(Lum::Button::typeCancel);
-  row->Add(button);
-
   vert->Add(row);
 
-  wGroup->SetMain(vert);
-
-  SetTop(wGroup);
+  SetMain(vert);
 
   Dialog::PreInit();
 }
