@@ -42,7 +42,6 @@
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
 #include <Lum/Text.h>
-#include <Lum/WindowGroup.h>
 
 // Game logic
 #include "Heap.h"
@@ -193,33 +192,13 @@ public:
     SetState(stateFinished);
   }
 
-  ~MainDialog()
-  {
-    UnattachModel(tableFadedAction);
-    UnattachModel(handFadedAction);
-    UnattachModel(handSelectionAction);
-
-    UnattachModel(aboutAction);
-    UnattachModel(lastComputerMoveAction);
-    UnattachModel(lastHumanMoveAction);
-    UnattachModel(newGameAction);
-
-    UnattachModel(GetOpenedAction());
-  }
-
   void PreInit()
   {
-    Lum::Button      *button;
-    Lum::Grid        *grid;
-    Lum::Label       *label;
-    Lum::Menu        *menu;
-    Lum::MenuStrip   *menuStrip;
-    Lum::Panel       *horiz,*vert;
-    Lum::Text        *text;
-    Lum::WindowGroup *wGroup;
-
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
+    Lum::Button *button;
+    Lum::Grid   *grid;
+    Lum::Label  *label;
+    Lum::Panel  *horiz,*vert;
+    Lum::Text   *text;
 
     horiz=new Lum::HPanel();
     horiz->SetFlex(true,true);
@@ -332,27 +311,24 @@ public:
 
     horiz->Add(vert);
 
-    wGroup->SetMain(horiz);
+    SetMain(horiz);
 
-    menuStrip=new Lum::MenuStrip();
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
 
-    menu=new Lum::Menu();
-    menu->AddActionItem(_ld(menuProjectQuit),GetClosedAction(),Lum::OS::qualifierControl,L"q");
-    menuStrip->AddPullDownMenu(_ld(menuProject),menu);
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(_(L"MENU_GAME",L"_Game"))
+        ->AddMenuItemAction(_(L"MENU_GAME_NEW",L"_New game"),Lum::OS::qualifierControl,L"g",newGameAction)
+        ->AddMenuItemAction(_(L"MENU_GAME_LAST_COMPUTER",L"_Show last _human move"),Lum::OS::qualifierControl,L"h",lastHumanMoveAction)
+        ->AddMenuItemAction(_(L"MENU_GAME_LAST_HUMAN",L"Show last _computer move"),Lum::OS::qualifierControl,L"c",lastComputerMoveAction);
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
 
-    menu=new Lum::Menu();
-    menu->AddActionItem(_(L"MENU_GAME_NEW",L"_New game"),newGameAction,Lum::OS::qualifierControl,L"g");
-    menu->AddActionItem(_(L"MENU_GAME_LAST_COMPUTER",L"_Show last _human move"),lastHumanMoveAction,Lum::OS::qualifierControl,L"h");
-    menu->AddActionItem(_(L"MENU_GAME_LAST_HUMAN",L"Show last _computer move"),lastComputerMoveAction,Lum::OS::qualifierControl,L"c");
-    menuStrip->AddPullDownMenu(_(L"MENU_GAME",L"_Game"),menu);
-
-    menu=new Lum::Menu();
-    menu->AddActionItem(_ld(menuHelpAbout),aboutAction);
-    menuStrip->AddPullDownMenu(_ld(menuHelp),menu);
-
-    wGroup->SetMenuStrip(menuStrip);
-
-    SetTop(wGroup);
+    SetMenu(menu);
 
     Dialog::PreInit();
   }
@@ -949,14 +925,17 @@ class Main : public Lum::OS::MainDialog<MainDialog>
 public:
   bool Prepare()
   {
-    bool result;
-
 #if defined(APP_DATADIR)
     Lum::Base::Path::SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
 #endif
 
-   result=Lum::OS::MainDialog<MainDialog>::Prepare();
+    srand(time(NULL));
 
+   return Lum::OS::MainDialog<MainDialog>::Prepare();
+  }
+
+  Main()
+  {
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
     info.SetDescription(_(L"ABOUT_DESC",L"Play a game of scopa with me..."));
@@ -964,15 +943,6 @@ public:
     info.SetContact(L"Tim Teulings <tim@teulings.org>");
     info.SetCopyright(L"(c) 2007, Tim Teulings");
     info.SetLicense(L"GNU Public License");
-
-    srand(time(NULL));
-
-    return result;
-  }
-
-  void Cleanup()
-  {
-    Lum::OS::MainDialog<MainDialog>::Cleanup();
   }
 };
 
